
# q-expansion of newform 4410.2.d.b, downloaded from the LMFDB on 08 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4410
weight = 2
poly_data = [390625, -468750, 328125, -168750, 70625, -21000, 4650, -420, -6, -84, 186, -168, 113, -54, 21, -6, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-198906250, 262743750, -114151250, 95015625, -32915700, 8780040, -870576, 415452, 259320, -27834, -101484, 103248, -49670, 25998, -7678, 189], 113625000], [[-346640625, 510212500, -263960625, 103996375, -48097950, 6932940, 199494, 88968, 790644, 488220, -129186, 157080, -86901, 37592, -5487, 1553], 340875000], [[-491250000, -69500000, 33712500, -64549375, 14222250, -15270150, -2041800, -12822, -736638, -29238, -120366, -19254, 46872, -26998, 4278, -3503], 568125000], [[-3281250, -606250, -1177500, -382375, 164850, -79170, -7452, -13746, -5610, -5118, -918, -354, -90, -104, -6, -47], 3375000], [[81562500, -1492703125, 1084443750, -557861875, 266151750, -79847700, 11659590, -6240882, 527442, 1249302, -162846, -463584, 336102, -195713, 58968, -28283], 1704375000], [[31171875, -22375000, 16706250, -7088125, 3376500, -1110600, 246270, -28224, 28464, -7506, 12828, -9648, 5859, -2816, 1326, -221], 11250000], [[4389921875, -7280656250, 3728618750, -2250321875, 552840000, -315330600, 81074310, -10144404, -7849236, -3946746, 1295088, -2564568, 1097059, -816586, 152446, -72631], 3408750000], [[-7956484375, 6112843750, -3710312500, 1666289375, -578292000, 74294100, -9287550, -5331624, -1678296, 1836654, -2848872, 2136732, -1227551, 538634, -180524, 28999], 1136250000], [[3061796875, -2635218750, 1557531250, -737662500, 287925000, -65558250, 10333650, -43854, -1282116, -369666, 1301988, -982878, 546479, -238236, 79646, -22146], 852187500], [[-1730156250, 1293390625, -926287500, 435921250, -165279750, 35428200, -7484130, -206466, 35346, 628476, -749898, 483708, -303924, 129881, -45366, 10646], 340875000], [[-8881406250, 10084203125, -4732575000, 2373254375, -869065500, 222951450, -31295250, -993864, 2386644, 3230094, -3388392, 2476302, -1660236, 730399, -239664, 63739], 1704375000], [[-22617265625, 19754156250, -12008093750, 5620186875, -1823016000, 612694800, -46368690, -9342132, 2114052, 8198442, -7941696, 8035536, -3465913, 1702962, -489382, 134847], 3408750000], [[17355937500, -16017953125, 8548481250, -3833020000, 1225090500, -328546950, 23859630, -6017556, 1982616, -6953964, 6806232, -5451762, 2832846, -1192979, 333594, -82424], 1704375000], [[-12730312500, 13369062500, -7391446875, 4053550625, -1325565750, 347872800, -45729360, 5982396, 6684504, 5948364, -4615362, 4791012, -2573376, 1157764, -393129, 113839], 1704375000], [[63741953125, -51938718750, 30395350000, -13935140625, 4897207500, -1103936400, 199376490, 39547164, 3731676, -17319114, 22180692, -18306312, 10377581, -4250574, 1400564, -298929], 3408750000]]

hecke_ring_character_values = [[3431, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2647, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1081, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, -1, 0], [0, 0, -1, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, 1, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 1, -1, 0, 0, -1, -1, -1, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0], [0, 0, -2, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, 2, 0], [0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, -1, 0, 1, 1, -1, 0, 0, 0, 1, 0, 0, 0, -1, 0], [0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1, 0, 1, 0, -1], [0, 0, 0, 0, 0, -1, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0], [-1, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, 1, 2, 1, 0, 1], [0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, -2, 1, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -3, 0, 0, 0, 0, 1, 0, 0, -1, 0, 1, 0, -3], [0, 0, -2, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 1, -2, 1, 0, 0], [0, 0, -1, 0, 0, -2, 0, 0, 0, 6, 2, 0, 0, 0, 1, 0], [0, 0, 1, 0, 1, -1, -2, 0, 0, 0, -1, 0, 0, 0, 1, 0], [0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0], [0, 0, 1, 0, -1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0], [-6, 0, 0, 1, 0, 0, 0, 2, -1, 0, 0, -2, 0, -2, 0, -1], [2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 0, 2, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 0, -2], [0, 0, 0, -4, 0, 0, 0, 0, -1, 0, 0, -2, 0, 2, 0, 0], [0, 0, -2, 0, -1, -1, 1, 0, 0, 0, -1, 0, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0, -2, -4, -2, 0, 0], [0, 0, 2, 0, 0, 2, 0, 0, 0, -2, -2, 0, 0, 0, -2, 0], [0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0], [-10, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0, -3, -4, -3, 0, -2], [0, 0, 3, 0, 7, 1, -1, 0, 0, 0, 1, 0, 0, 0, 3, 0], [0, 0, 0, -1, 0, 0, 0, 0, -1, 0, 0, 1, 0, -1, 0, 1], [0, -1, -1, 0, 0, -5, 0, 0, 0, 3, 5, 0, 0, 0, 1, 0], [0, 0, -1, 0, 0, -2, 0, 0, 0, -3, 2, 0, 0, 0, 1, 0], [0, 0, 0, 4, 0, 0, 0, 0, -3, 0, 0, 1, 0, -1, 0, 0], [0, 2, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -3, 0, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, -3], [6, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0], [-3, 0, 0, -2, 0, 0, 0, -2, 2, 0, 0, 1, 2, 1, 0, 2], [0, 0, 3, 0, 3, 0, -4, 0, 0, 0, 0, 0, 0, 0, 3, 0], [0, 2, -1, 0, 0, -2, 0, 0, 0, 6, 2, 0, 0, 0, 1, 0], [0, 0, 2, 0, 0, 2, 0, 0, 0, -4, -2, 0, 0, 0, -2, 0], [4, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, -1, 2, -1, 0, 1], [0, 0, 0, 9, 0, 0, 0, 0, -1, 0, 0, -1, 0, 1, 0, -3], [0, 1, 2, 0, 0, -1, 0, 0, 0, 1, 1, 0, 0, 0, -2, 0], [0, 0, -1, 0, 8, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0], [0, -2, 0, 0, 0, 2, 0, 0, 0, 6, -2, 0, 0, 0, 0, 0], [-14, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1, -2, -1, 0, -1], [0, 0, -4, 0, -6, -1, 2, 0, 0, 0, -1, 0, 0, 0, -4, 0], [0, 0, 4, 0, 0, 1, 0, 0, 0, -2, -1, 0, 0, 0, -4, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 3, 0, -3, 0, 1], [0, 0, 0, -10, 0, 0, 0, 0, -1, 0, 0, -3, 0, 3, 0, 0], [0, 0, 3, 0, 2, -1, 2, 0, 0, 0, -1, 0, 0, 0, 3, 0], [0, -1, -5, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 5, 0], [0, 0, -3, 0, -10, -1, 2, 0, 0, 0, -1, 0, 0, 0, -3, 0], [0, 0, 4, 0, 0, -4, -2, 0, 0, 0, -4, 0, 0, 0, 4, 0], [0, 0, -1, 0, -8, -4, -2, 0, 0, 0, -4, 0, 0, 0, -1, 0], [-10, 0, 0, 4, 0, 0, 0, 2, -4, 0, 0, -1, -6, -1, 0, -4], [-4, 0, 0, 0, 0, 0, 0, -3, 0, 0, 0, 0, -3, 0, 0, 0], [0, 0, 0, -3, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, -5], [-10, 0, 0, -2, 0, 0, 0, 2, 2, 0, 0, 2, 6, 2, 0, 2], [0, 0, -4, 0, 0, 2, 0, 0, 0, -4, -2, 0, 0, 0, 4, 0], [0, -2, 0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0], [0, 0, 0, 8, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, -6], [0, 0, -2, 0, 0, -1, -3, 0, 0, 0, -1, 0, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -3, 0, 3, 0, -1], [7, 0, 0, -1, 0, 0, 0, -4, 1, 0, 0, 2, -2, 2, 0, 1], [0, 0, 3, 0, 0, -4, 0, 0, 0, -3, 4, 0, 0, 0, -3, 0], [0, 0, 0, 12, 0, 0, 0, 0, 2, 0, 0, 2, 0, -2, 0, 0], [0, 0, 5, 0, 11, -3, -2, 0, 0, 0, -3, 0, 0, 0, 5, 0], [0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3], [0, -2, 1, 0, 0, 4, 0, 0, 0, -12, -4, 0, 0, 0, -1, 0], [0, 0, -3, 0, -5, -3, 3, 0, 0, 0, -3, 0, 0, 0, -3, 0], [-14, 0, 0, 1, 0, 0, 0, 2, -1, 0, 0, -1, 0, -1, 0, -1], [0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6], [0, 0, 2, 0, 10, 2, 4, 0, 0, 0, 2, 0, 0, 0, 2, 0], [0, -2, 2, 0, 0, -1, 0, 0, 0, -6, 1, 0, 0, 0, -2, 0], [8, 0, 0, -1, 0, 0, 0, 2, 1, 0, 0, 2, 4, 2, 0, 1], [0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 1, 0, -1, 0, 6], [0, 0, 0, -17, 0, 0, 0, 0, 3, 0, 0, 2, 0, -2, 0, 3], [0, 0, -2, 0, 4, 4, 4, 0, 0, 0, 4, 0, 0, 0, -2, 0], [0, 0, 0, 4, 0, 0, 0, 0, -4, 0, 0, 2, 0, -2, 0, 1], [0, -2, -4, 0, 0, -2, 0, 0, 0, 6, 2, 0, 0, 0, 4, 0], [0, 0, 5, 0, 2, -1, -4, 0, 0, 0, -1, 0, 0, 0, 5, 0], [0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, -9, 0, 0, 0, 0, 4, 0, 0, 5, 0, -5, 0, 6], [12, 0, 0, -2, 0, 0, 0, -2, 2, 0, 0, 4, 2, 4, 0, 2], [0, 4, 1, 0, 0, -3, 0, 0, 0, 0, 3, 0, 0, 0, -1, 0], [0, 0, -4, 0, -8, -3, 2, 0, 0, 0, -3, 0, 0, 0, -4, 0], [0, 0, -6, 0, -1, 0, 3, 0, 0, 0, 0, 0, 0, 0, -6, 0], [0, 0, 5, 0, 0, -5, 4, 0, 0, 0, -5, 0, 0, 0, 5, 0], [-8, 0, 0, 1, 0, 0, 0, -4, -1, 0, 0, -7, -6, -7, 0, -1], [0, 0, 0, -9, 0, 0, 0, 0, 1, 0, 0, 3, 0, -3, 0, 5], [-7, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -5, -2, -5, 0, -1], [0, 2, -1, 0, 0, -2, 0, 0, 0, -6, 2, 0, 0, 0, 1, 0], [0, 0, 0, 3, 0, 0, 0, 0, 1, 0, 0, -1, 0, 1, 0, 6], [10, 0, 0, -3, 0, 0, 0, -4, 3, 0, 0, 5, 2, 5, 0, 3], [0, 0, 1, 0, 8, -2, 0, 0, 0, 0, -2, 0, 0, 0, 1, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, -6, 0, 0, 0, 0, -1, 0], [0, 4, -5, 0, 0, -3, 0, 0, 0, 0, 3, 0, 0, 0, 5, 0], [0, 0, 0, 10, 0, 0, 0, 0, 4, 0, 0, -2, 0, 2, 0, 0], [0, 0, -1, 0, 0, -4, 0, 0, 0, 14, 4, 0, 0, 0, 1, 0], [0, 0, 0, 0, 12, 3, 5, 0, 0, 0, 3, 0, 0, 0, 0, 0], [0, 0, 0, -5, 0, 0, 0, 0, 2, 0, 0, 2, 0, -2, 0, -1], [-18, 0, 0, -3, 0, 0, 0, -4, 3, 0, 0, 1, 2, 1, 0, 3], [0, 2, 2, 0, 0, -1, 0, 0, 0, -11, 1, 0, 0, 0, -2, 0], [-18, 0, 0, 4, 0, 0, 0, 4, -4, 0, 0, 1, -4, 1, 0, -4], [0, 0, 0, 5, 0, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0, -9], [0, 0, 0, 0, -2, -2, 2, 0, 0, 0, -2, 0, 0, 0, 0, 0], [0, -4, 4, 0, 0, -3, 0, 0, 0, 9, 3, 0, 0, 0, -4, 0], [8, 0, 0, -2, 0, 0, 0, -9, 2, 0, 0, -5, -5, -5, 0, 2], [0, 0, 0, 4, 0, 0, 0, 0, -7, 0, 0, 1, 0, -1, 0, -3], [0, 2, 1, 0, 0, -5, 0, 0, 0, 6, 5, 0, 0, 0, -1, 0], [0, 0, 0, 15, 0, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, -1], [0, 3, 3, 0, 0, 2, 0, 0, 0, 15, -2, 0, 0, 0, -3, 0], [6, 0, 0, 3, 0, 0, 0, -2, -3, 0, 0, -4, -8, -4, 0, -3], [0, 4, -2, 0, 0, -2, 0, 0, 0, 0, 2, 0, 0, 0, 2, 0], [0, 0, 0, -14, 0, 0, 0, 0, -2, 0, 0, 1, 0, -1, 0, 0], [14, 0, 0, 4, 0, 0, 0, 6, -4, 0, 0, 0, -2, 0, 0, -4], [0, 0, 6, 0, 6, -4, -6, 0, 0, 0, -4, 0, 0, 0, 6, 0], [0, 0, 4, 0, 0, -7, 3, 0, 0, 0, -7, 0, 0, 0, 4, 0], [0, 0, 4, 0, 3, 8, -3, 0, 0, 0, 8, 0, 0, 0, 4, 0], [0, 0, 0, 4, 0, 0, 0, 1, -4, 0, 0, -2, -7, -2, 0, -4], [7, 0, 0, -3, 0, 0, 0, -6, 3, 0, 0, 2, 0, 2, 0, 3], [2, 0, 0, -4, 0, 0, 0, -6, 4, 0, 0, 3, 2, 3, 0, 4], [0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 0, -4, 0, 4, 0, -6], [0, 0, 3, 0, 10, -1, -3, 0, 0, 0, -1, 0, 0, 0, 3, 0], [0, -3, 2, 0, 0, -7, 0, 0, 0, 1, 7, 0, 0, 0, -2, 0], [0, 3, 1, 0, 0, -3, 0, 0, 0, -9, 3, 0, 0, 0, -1, 0], [0, 0, 3, 0, 14, -1, 2, 0, 0, 0, -1, 0, 0, 0, 3, 0], [0, -2, 2, 0, 0, 7, 0, 0, 0, -6, -7, 0, 0, 0, -2, 0], [0, 0, 0, 18, 0, 0, 0, 0, -2, 0, 0, 2, 0, -2, 0, 3], [0, -6, 1, 0, 0, -2, 0, 0, 0, 3, 2, 0, 0, 0, -1, 0], [0, 0, 0, -12, 0, 0, 0, 0, -6, 0, 0, -1, 0, 1, 0, 0], [0, 0, 0, 8, 0, 0, 0, 0, 1, 0, 0, -5, 0, 5, 0, -3], [-22, 0, 0, 1, 0, 0, 0, -4, -1, 0, 0, -4, -6, -4, 0, -1], [0, 4, -3, 0, 0, -3, 0, 0, 0, 8, 3, 0, 0, 0, 3, 0], [0, 0, 1, 0, -8, 1, -2, 0, 0, 0, 1, 0, 0, 0, 1, 0], [0, 0, -5, 0, -7, -5, -3, 0, 0, 0, -5, 0, 0, 0, -5, 0], [0, -4, -3, 0, 0, 11, 0, 0, 0, 6, -11, 0, 0, 0, 3, 0], [0, 0, 1, 0, 0, 13, 0, 0, 0, -4, -13, 0, 0, 0, -1, 0], [-6, 0, 0, 4, 0, 0, 0, 5, -4, 0, 0, 4, -3, 4, 0, -4], [0, 0, 0, -28, 0, 0, 0, 0, -2, 0, 0, -2, 0, 2, 0, -1], [0, 0, -2, 0, -4, -2, 1, 0, 0, 0, -2, 0, 0, 0, -2, 0], [0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 4, 0, -4, 0, 0], [0, 0, 3, 0, 0, -7, 0, 0, 0, 18, 7, 0, 0, 0, -3, 0], [0, 0, 0, -3, 0, 0, 0, 0, -1, 0, 0, -3, 0, 3, 0, -11], [0, 0, 0, -7, 0, 0, 0, 0, -5, 0, 0, -3, 0, 3, 0, 3], [-34, 0, 0, 0, 0, 0, 0, -6, 0, 0, 0, -6, -6, -6, 0, 0], [0, 0, 12, 0, 11, 2, 3, 0, 0, 0, 2, 0, 0, 0, 12, 0], [0, 0, -3, 0, 2, 2, 2, 0, 0, 0, 2, 0, 0, 0, -3, 0], [0, 0, 4, 0, -2, -3, -8, 0, 0, 0, -3, 0, 0, 0, 4, 0], [-12, 0, 0, -6, 0, 0, 0, -12, 6, 0, 0, 0, 0, 0, 0, 6], [-10, 0, 0, 1, 0, 0, 0, 2, -1, 0, 0, 5, 0, 5, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 6, 0, -6, 0, 1], [0, 0, 4, 0, -5, -1, 1, 0, 0, 0, -1, 0, 0, 0, 4, 0], [-14, 0, 0, 5, 0, 0, 0, 4, -5, 0, 0, 1, -6, 1, 0, -5], [0, 4, 1, 0, 0, 12, 0, 0, 0, -3, -12, 0, 0, 0, -1, 0], [10, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, -7, 2, -7, 0, 0], [0, 0, -3, 0, 11, -1, 2, 0, 0, 0, -1, 0, 0, 0, -3, 0], [8, 0, 0, 3, 0, 0, 0, 3, -3, 0, 0, -6, -3, -6, 0, -3], [0, 2, 3, 0, 0, 5, 0, 0, 0, -3, -5, 0, 0, 0, -3, 0], [0, 0, 0, 3, 0, 0, 0, 0, 6, 0, 0, -1, 0, 1, 0, 0], [0, 0, -5, 0, 0, -11, 0, 0, 0, 4, 11, 0, 0, 0, 5, 0], [0, 0, 0, 9, 0, 0, 0, 0, 1, 0, 0, 5, 0, -5, 0, -3], [0, 0, 0, 21, 0, 0, 0, 0, -7, 0, 0, 0, 0, 0, 0, -5], [0, -2, 0, 0, 0, -3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0], [0, 0, 7, 0, -3, -5, -2, 0, 0, 0, -5, 0, 0, 0, 7, 0], [-11, 0, 0, -4, 0, 0, 0, -10, 4, 0, 0, -1, -2, -1, 0, 4], [0, 0, 0, -6, 0, 0, 0, 0, 4, 0, 0, -1, 0, 1, 0, 0], [0, 0, 4, 0, -4, -14, -3, 0, 0, 0, -14, 0, 0, 0, 4, 0], [0, 2, -3, 0, 0, -9, 0, 0, 0, 6, 9, 0, 0, 0, 3, 0], [0, 0, 0, -10, 0, 0, 0, 0, -3, 0, 0, 4, 0, -4, 0, 6], [0, 0, 12, 0, 11, -3, -3, 0, 0, 0, -3, 0, 0, 0, 12, 0], [0, 0, 0, 20, 0, 0, 0, 0, 3, 0, 0, 1, 0, -1, 0, 4], [0, 4, 6, 0, 0, -4, 0, 0, 0, 0, 4, 0, 0, 0, -6, 0], [25, 0, 0, 3, 0, 0, 0, -2, -3, 0, 0, -2, -8, -2, 0, -3], [0, 0, 6, 0, -4, 7, -6, 0, 0, 0, 7, 0, 0, 0, 6, 0], [0, 0, 0, -5, 0, 0, 0, 0, 7, 0, 0, 5, 0, -5, 0, 2], [0, 0, 8, 0, 4, 2, 4, 0, 0, 0, 2, 0, 0, 0, 8, 0], [28, 0, 0, 1, 0, 0, 0, -7, -1, 0, 0, -4, -9, -4, 0, -1], [0, 0, 11, 0, 16, 3, 2, 0, 0, 0, 3, 0, 0, 0, 11, 0], [0, 0, 7, 0, 12, -4, 0, 0, 0, 0, -4, 0, 0, 0, 7, 0], [-2, 0, 0, -7, 0, 0, 0, 2, 7, 0, 0, 6, 16, 6, 0, 7], [15, 0, 0, -6, 0, 0, 0, -2, 6, 0, 0, 1, 10, 1, 0, 6], [0, 0, -4, 0, -8, 2, -4, 0, 0, 0, 2, 0, 0, 0, -4, 0], [2, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, -2, 2, -2, 0, 1], [0, -2, 10, 0, 0, 0, 0, 0, 0, -18, 0, 0, 0, 0, -10, 0], [-3, 0, 0, 7, 0, 0, 0, 4, -7, 0, 0, -2, -10, -2, 0, -7], [0, 0, 0, 21, 0, 0, 0, 0, -6, 0, 0, 0, 0, 0, 0, -6], [0, 6, -3, 0, 0, 11, 0, 0, 0, -12, -11, 0, 0, 0, 3, 0], [0, -8, 5, 0, 0, 7, 0, 0, 0, 0, -7, 0, 0, 0, -5, 0], [0, 0, 0, 4, 0, 0, 0, 0, -2, 0, 0, -5, 0, 5, 0, -6], [0, 6, 4, 0, 0, 4, 0, 0, 0, 2, -4, 0, 0, 0, -4, 0], [0, 0, -3, 0, 11, 11, 2, 0, 0, 0, 11, 0, 0, 0, -3, 0], [0, -5, -7, 0, 0, -1, 0, 0, 0, -11, 1, 0, 0, 0, 7, 0], [0, 0, 9, 0, -3, -9, 0, 0, 0, 0, -9, 0, 0, 0, 9, 0], [0, 1, 7, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, -7, 0], [0, 0, -4, 0, 0, -10, 0, 0, 0, 22, 10, 0, 0, 0, 4, 0], [22, 0, 0, -7, 0, 0, 0, -4, 7, 0, 0, 0, 10, 0, 0, 7], [0, 0, 0, -21, 0, 0, 0, 0, 2, 0, 0, -4, 0, 4, 0, -3], [0, 3, 3, 0, 0, 9, 0, 0, 0, -15, -9, 0, 0, 0, -3, 0], [0, 0, 0, -6, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, -8], [0, 0, 8, 0, 4, 1, -10, 0, 0, 0, 1, 0, 0, 0, 8, 0], [0, 0, 0, -8, 0, 0, 0, 0, 7, 0, 0, 2, 0, -2, 0, -1], [0, 0, -5, 0, 0, 6, 0, 0, 0, 0, -6, 0, 0, 0, 5, 0], [0, 0, -7, 0, -8, 5, -4, 0, 0, 0, 5, 0, 0, 0, -7, 0], [0, -6, 1, 0, 0, -8, 0, 0, 0, 9, 8, 0, 0, 0, -1, 0], [0, 0, 0, -16, 0, 0, 0, 0, 1, 0, 0, -8, 0, 8, 0, 0], [0, 0, 1, 0, 10, 5, 1, 0, 0, 0, 5, 0, 0, 0, 1, 0], [-11, 0, 0, -3, 0, 0, 0, -6, 3, 0, 0, -4, 0, -4, 0, 3], [17, 0, 0, -1, 0, 0, 0, -2, 1, 0, 0, 0, 0, 0, 0, 1], [16, 0, 0, 6, 0, 0, 0, 8, -6, 0, 0, 2, -4, 2, 0, -6], [0, 2, -8, 0, 0, 4, 0, 0, 0, -8, -4, 0, 0, 0, 8, 0], [0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, -4, 0, 4, 0, -3], [0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 5, 0, -5, 0, 7], [0, 2, -5, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 5, 0], [10, 0, 0, 4, 0, 0, 0, 2, -4, 0, 0, 2, -6, 2, 0, -4], [0, 4, -6, 0, 0, 2, 0, 0, 0, -6, -2, 0, 0, 0, 6, 0], [0, 0, 0, 10, 0, 0, 0, 0, -10, 0, 0, -2, 0, 2, 0, 0], [0, 0, 11, 0, 11, 0, -11, 0, 0, 0, 0, 0, 0, 0, 11, 0], [0, 0, 0, 16, 0, 0, 0, 0, -7, 0, 0, 1, 0, -1, 0, -3], [0, 0, 0, -9, 0, 0, 0, 0, 3, 0, 0, -3, 0, 3, 0, 6], [0, 2, 7, 0, 0, 4, 0, 0, 0, -7, -4, 0, 0, 0, -7, 0], [24, 0, 0, -6, 0, 0, 0, -8, 6, 0, 0, -5, 4, -5, 0, 6], [0, 0, 0, -8, 0, 0, 0, 0, 4, 0, 0, -2, 0, 2, 0, -3], [0, 0, 2, 0, 12, 4, -2, 0, 0, 0, 4, 0, 0, 0, 2, 0], [0, 4, 7, 0, 0, -3, 0, 0, 0, 6, 3, 0, 0, 0, -7, 0], [0, -2, -7, 0, 0, 2, 0, 0, 0, 8, -2, 0, 0, 0, 7, 0], [24, 0, 0, -2, 0, 0, 0, -1, 2, 0, 0, 7, 3, 7, 0, 2], [0, 0, 0, -6, 0, 0, 0, 0, 5, 0, 0, 5, 0, -5, 0, 6], [0, 0, -15, 0, -14, 1, 6, 0, 0, 0, 1, 0, 0, 0, -15, 0], [-18, 0, 0, 4, 0, 0, 0, -4, -4, 0, 0, -8, -12, -8, 0, -4], [0, -3, -3, 0, 0, -3, 0, 0, 0, -17, 3, 0, 0, 0, 3, 0], [0, 0, -7, 0, -3, 10, 4, 0, 0, 0, 10, 0, 0, 0, -7, 0], [-14, 0, 0, 2, 0, 0, 0, 14, -2, 0, 0, 2, 10, 2, 0, -2], [0, 0, 3, 0, 0, 5, 0, 0, 0, -12, -5, 0, 0, 0, -3, 0], [0, 0, 0, 0, 10, 4, 6, 0, 0, 0, 4, 0, 0, 0, 0, 0], [0, 0, 5, 0, 7, 8, 1, 0, 0, 0, 8, 0, 0, 0, 5, 0], [0, 0, 4, 0, 6, -4, 7, 0, 0, 0, -4, 0, 0, 0, 4, 0], [12, 0, 0, -8, 0, 0, 0, -2, 8, 0, 0, 4, 14, 4, 0, 8], [-2, 0, 0, 2, 0, 0, 0, -5, -2, 0, 0, -8, -9, -8, 0, -2], [0, 0, 0, -2, 0, 0, 0, 0, 5, 0, 0, -1, 0, 1, 0, 7], [0, 0, -13, 0, -10, 5, 11, 0, 0, 0, 5, 0, 0, 0, -13, 0], [6, 0, 0, -2, 0, 0, 0, -3, 2, 0, 0, 6, 1, 6, 0, 2], [0, 2, 1, 0, 0, -8, 0, 0, 0, 11, 8, 0, 0, 0, -1, 0], [0, -2, -2, 0, 0, -9, 0, 0, 0, 30, 9, 0, 0, 0, 2, 0], [0, 0, 0, -7, 0, 0, 0, 0, 3, 0, 0, -6, 0, 6, 0, -6], [-24, 0, 0, 7, 0, 0, 0, 4, -7, 0, 0, -5, -10, -5, 0, -7], [0, 0, 8, 0, 0, -8, -8, 0, 0, 0, -8, 0, 0, 0, 8, 0], [0, -6, 3, 0, 0, -7, 0, 0, 0, 3, 7, 0, 0, 0, -3, 0], [0, 0, -7, 0, 6, -2, 10, 0, 0, 0, -2, 0, 0, 0, -7, 0], [0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, -3, 0, 3, 0, -2], [8, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -8, -2, -8, 0, -1], [0, 4, 0, 0, 0, -12, 0, 0, 0, -6, 12, 0, 0, 0, 0, 0], [0, 0, 1, 0, 9, 5, 6, 0, 0, 0, 5, 0, 0, 0, 1, 0], [0, -6, 3, 0, 0, -1, 0, 0, 0, 18, 1, 0, 0, 0, -3, 0], [0, 1, 3, 0, 0, -3, 0, 0, 0, 3, 3, 0, 0, 0, -3, 0], [0, 0, 0, 30, 0, 0, 0, 0, -4, 0, 0, -1, 0, 1, 0, 6], [0, 0, -2, 0, -5, 10, -5, 0, 0, 0, 10, 0, 0, 0, -2, 0], [0, 0, 0, 6, 0, 0, 0, 0, -16, 0, 0, 0, 0, 0, 0, -14], [20, 0, 0, -4, 0, 0, 0, -1, 4, 0, 0, 5, 7, 5, 0, 4], [0, -2, 2, 0, 0, 20, 0, 0, 0, -4, -20, 0, 0, 0, -2, 0], [0, 0, 0, 4, 0, 0, 0, 0, -6, 0, 0, 8, 0, -8, 0, 2], [0, 0, 5, 0, 4, 2, 4, 0, 0, 0, 2, 0, 0, 0, 5, 0], [14, 0, 0, 2, 0, 0, 0, 6, -2, 0, 0, 9, 2, 9, 0, -2], [0, 0, 1, 0, 6, 8, -6, 0, 0, 0, 8, 0, 0, 0, 1, 0], [0, 0, -10, 0, -8, -4, 7, 0, 0, 0, -4, 0, 0, 0, -10, 0], [-8, 0, 0, 7, 0, 0, 0, 14, -7, 0, 0, 0, 0, 0, 0, -7], [-10, 0, 0, 3, 0, 0, 0, 6, -3, 0, 0, 3, 0, 3, 0, -3], [5, 0, 0, 1, 0, 0, 0, 12, -1, 0, 0, 6, 10, 6, 0, -1], [0, 0, -10, 0, -18, 10, 5, 0, 0, 0, 10, 0, 0, 0, -10, 0], [0, -1, -12, 0, 0, 2, 0, 0, 0, -3, -2, 0, 0, 0, 12, 0], [8, 0, 0, 6, 0, 0, 0, 12, -6, 0, 0, 3, 0, 3, 0, -6], [0, -4, -2, 0, 0, -3, 0, 0, 0, -15, 3, 0, 0, 0, 2, 0], [0, -8, -2, 0, 0, -2, 0, 0, 0, -4, 2, 0, 0, 0, 2, 0], [0, 0, 0, 0, 2, 14, -4, 0, 0, 0, 14, 0, 0, 0, 0, 0], [0, 0, 0, 19, 0, 0, 0, 0, -9, 0, 0, -5, 0, 5, 0, -3], [0, 0, 0, 17, 0, 0, 0, 0, -9, 0, 0, 4, 0, -4, 0, -7], [-28, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 3, 7, 3, 0, 0], [0, 0, 2, 0, 0, -1, 0, 0, 0, -14, 1, 0, 0, 0, -2, 0], [0, 0, -3, 0, 3, 15, -3, 0, 0, 0, 15, 0, 0, 0, -3, 0], [0, 0, 0, -14, 0, 0, 0, 0, 4, 0, 0, 4, 0, -4, 0, 6], [0, 4, -7, 0, 0, -14, 0, 0, 0, 18, 14, 0, 0, 0, 7, 0], [2, 0, 0, 8, 0, 0, 0, 6, -8, 0, 0, -2, -10, -2, 0, -8], [0, 0, -16, 0, -10, 2, 5, 0, 0, 0, 2, 0, 0, 0, -16, 0], [0, 0, 0, -9, 0, 0, 0, 0, -2, 0, 0, -6, 0, 6, 0, -1], [0, 0, 0, 0, -20, -5, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0], [0, 4, 2, 0, 0, -10, 0, 0, 0, 0, 10, 0, 0, 0, -2, 0], [0, 0, -2, 0, 0, 0, 0, 0, 0, 24, 0, 0, 0, 0, 2, 0], [0, 0, 3, 0, 3, -1, -9, 0, 0, 0, -1, 0, 0, 0, 3, 0], [0, 0, 1, 0, -2, -3, -6, 0, 0, 0, -3, 0, 0, 0, 1, 0], [0, 0, 6, 0, -6, 6, -4, 0, 0, 0, 6, 0, 0, 0, 6, 0], [0, 0, 0, 4, 0, 0, 0, -1, -4, 0, 0, -5, -9, -5, 0, -4], [4, 0, 0, 6, 0, 0, 0, 8, -6, 0, 0, -7, -4, -7, 0, -6], [12, 0, 0, -3, 0, 0, 0, 2, 3, 0, 0, -8, 8, -8, 0, 3], [22, 0, 0, 7, 0, 0, 0, 8, -7, 0, 0, -1, -6, -1, 0, -7], [0, 0, 0, -14, 0, 0, 0, 0, 6, 0, 0, -4, 0, 4, 0, -12], [8, 0, 0, 1, 0, 0, 0, 4, -1, 0, 0, 6, 2, 6, 0, -1], [0, 2, 6, 0, 0, 12, 0, 0, 0, 10, -12, 0, 0, 0, -6, 0], [0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -10, 0, 0, 0, 0, 12, 0, 0, -2, 0, 2, 0, 1], [0, 5, -3, 0, 0, 5, 0, 0, 0, 9, -5, 0, 0, 0, 3, 0], [0, 0, 0, 18, 0, 0, 0, 0, -8, 0, 0, 8, 0, -8, 0, 0], [0, 0, 0, -9, 0, 0, 0, 0, -6, 0, 0, -4, 0, 4, 0, -6], [0, 0, 0, -26, 0, 0, 0, 0, 0, 0, 0, -4, 0, 4, 0, -12], [3, 0, 0, 4, 0, 0, 0, 12, -4, 0, 0, -3, 4, -3, 0, -4], [0, -7, 3, 0, 0, 3, 0, 0, 0, -1, -3, 0, 0, 0, -3, 0], [0, 0, 5, 0, 0, -4, -13, 0, 0, 0, -4, 0, 0, 0, 5, 0], [0, 0, 0, 5, 0, 0, 0, 0, -3, 0, 0, -3, 0, 3, 0, -9], [0, 0, 1, 0, 6, 14, 0, 0, 0, 0, 14, 0, 0, 0, 1, 0], [0, 0, 0, 6, 0, 0, 0, 0, -5, 0, 0, -1, 0, 1, 0, -3], [0, 8, 4, 0, 0, 4, 0, 0, 0, 4, -4, 0, 0, 0, -4, 0], [0, 0, 0, 4, 0, 0, 0, 0, -4, 0, 0, -10, 0, 10, 0, -10], [0, 0, 2, 0, -18, -5, -4, 0, 0, 0, -5, 0, 0, 0, 2, 0], [0, 0, 0, 10, 0, 0, 0, 0, -3, 0, 0, -1, 0, 1, 0, 12], [-42, 0, 0, -4, 0, 0, 0, -10, 4, 0, 0, -2, -2, -2, 0, 4], [0, 7, -12, 0, 0, -3, 0, 0, 0, 19, 3, 0, 0, 0, 12, 0], [-27, 0, 0, 4, 0, 0, 0, -2, -4, 0, 0, -5, -10, -5, 0, -4], [0, 0, 0, 0, 10, -2, 8, 0, 0, 0, -2, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, -6, 0, 0], [-16, 0, 0, 4, 0, 0, 0, 14, -4, 0, 0, -1, 6, -1, 0, -4], [-12, 0, 0, -7, 0, 0, 0, -2, 7, 0, 0, 1, 12, 1, 0, 7], [-16, 0, 0, -6, 0, 0, 0, -10, 6, 0, 0, -1, 2, -1, 0, 6], [0, -2, 8, 0, 0, -4, 0, 0, 0, -16, 4, 0, 0, 0, -8, 0], [0, -2, 4, 0, 0, -6, 0, 0, 0, 24, 6, 0, 0, 0, -4, 0], [-37, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 1], [0, 4, -6, 0, 0, -4, 0, 0, 0, 12, 4, 0, 0, 0, 6, 0], [-2, 0, 0, 3, 0, 0, 0, 14, -3, 0, 0, 11, 8, 11, 0, -3], [0, -6, 1, 0, 0, 15, 0, 0, 0, -12, -15, 0, 0, 0, -1, 0], [0, 0, -8, 0, 0, 4, 0, 0, 0, -5, -4, 0, 0, 0, 8, 0], [0, 0, -1, 0, -5, -4, 1, 0, 0, 0, -4, 0, 0, 0, -1, 0], [0, 0, 0, 3, 0, 0, 0, 0, -10, 0, 0, 0, 0, 0, 0, 10], [14, 0, 0, 9, 0, 0, 0, 6, -9, 0, 0, -5, -12, -5, 0, -9], [0, 0, -2, 0, 0, 13, -2, 0, 0, 0, 13, 0, 0, 0, -2, 0], [10, 0, 0, 2, 0, 0, 0, 14, -2, 0, 0, 11, 10, 11, 0, -2], [-28, 0, 0, -2, 0, 0, 0, 2, 2, 0, 0, -1, 6, -1, 0, 2], [0, 0, 0, -3, 0, 0, 0, 0, 14, 0, 0, 5, 0, -5, 0, 0], [0, -4, 4, 0, 0, -8, 0, 0, 0, -10, 8, 0, 0, 0, -4, 0], [0, 0, 0, 2, 0, 0, 0, 0, 14, 0, 0, 4, 0, -4, 0, 0], [0, 0, 2, 0, 24, 8, 2, 0, 0, 0, 8, 0, 0, 0, 2, 0], [0, -10, -11, 0, 0, 3, 0, 0, 0, -9, -3, 0, 0, 0, 11, 0], [0, -2, 8, 0, 0, -1, 0, 0, 0, -31, 1, 0, 0, 0, -8, 0], [0, 0, 0, 11, 0, 0, 0, 0, 5, 0, 0, 4, 0, -4, 0, 11], [0, 0, 0, 6, 0, 0, 0, 0, 8, 0, 0, -4, 0, 4, 0, 6], [0, 0, -18, 0, -16, 5, 5, 0, 0, 0, 5, 0, 0, 0, -18, 0], [30, 0, 0, -1, 0, 0, 0, 10, 1, 0, 0, 13, 12, 13, 0, 1], [0, -8, 1, 0, 0, -3, 0, 0, 0, 0, 3, 0, 0, 0, -1, 0], [0, 0, 3, 0, -8, -7, -12, 0, 0, 0, -7, 0, 0, 0, 3, 0], [0, 0, -2, 0, -5, -11, -8, 0, 0, 0, -11, 0, 0, 0, -2, 0], [50, 0, 0, -4, 0, 0, 0, 0, 4, 0, 0, 10, 8, 10, 0, 4], [0, 0, 0, 2, 0, 0, 0, 10, -2, 0, 0, 8, 6, 8, 0, -2], [0, 0, 0, 1, 0, 0, 0, 0, -7, 0, 0, -1, 0, 1, 0, 2], [0, 0, 11, 0, 9, -5, -10, 0, 0, 0, -5, 0, 0, 0, 11, 0], [12, 0, 0, -4, 0, 0, 0, -8, 4, 0, 0, 2, 0, 2, 0, 4], [0, 0, 0, -12, 0, 0, 0, 0, 10, 0, 0, 2, 0, -2, 0, 9], [0, 0, 9, 0, -4, -13, 8, 0, 0, 0, -13, 0, 0, 0, 9, 0], [0, 0, 0, -3, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, -3], [0, -4, -3, 0, 0, 8, 0, 0, 0, -3, -8, 0, 0, 0, 3, 0], [0, 0, 0, 14, 0, 0, 0, 0, 10, 0, 0, 4, 0, -4, 0, -7], [-4, 0, 0, 3, 0, 0, 0, -3, -3, 0, 0, -6, -9, -6, 0, -3], [0, 0, 0, -1, 0, 0, 0, 0, -11, 0, 0, 0, 0, 0, 0, -6], [0, -2, 7, 0, 0, -14, 0, 0, 0, 31, 14, 0, 0, 0, -7, 0], [-12, 0, 0, -4, 0, 0, 0, 4, 4, 0, 0, 2, 12, 2, 0, 4], [0, 0, 0, -4, 0, 0, 0, 0, 4, 0, 0, -9, 0, 9, 0, -12], [0, -6, -2, 0, 0, -8, 0, 0, 0, 18, 8, 0, 0, 0, 2, 0], [0, 0, 0, 13, 0, 0, 0, 0, 8, 0, 0, -4, 0, 4, 0, 4], [0, 0, 9, 0, 7, 1, -9, 0, 0, 0, 1, 0, 0, 0, 9, 0], [0, 0, 0, 9, 0, 0, 0, 0, 1, 0, 0, 5, 0, -5, 0, 9], [0, 0, -1, 0, 10, 14, -2, 0, 0, 0, 14, 0, 0, 0, -1, 0], [0, 0, 1, 0, -5, -13, -2, 0, 0, 0, -13, 0, 0, 0, 1, 0], [0, 0, 2, 0, -4, 0, -8, 0, 0, 0, 0, 0, 0, 0, 2, 0], [0, 0, 8, 0, 24, 6, 2, 0, 0, 0, 6, 0, 0, 0, 8, 0], [-2, 0, 0, 9, 0, 0, 0, 18, -9, 0, 0, 5, 0, 5, 0, -9], [0, 0, 0, 26, 0, 0, 0, 0, 6, 0, 0, -8, 0, 8, 0, -3], [30, 0, 0, -3, 0, 0, 0, -4, 3, 0, 0, -5, 2, -5, 0, 3], [0, 2, -8, 0, 0, 13, 0, 0, 0, 1, -13, 0, 0, 0, 8, 0], [0, 7, 6, 0, 0, -4, 0, 0, 0, -3, 4, 0, 0, 0, -6, 0], [8, 0, 0, 4, 0, 0, 0, 12, -4, 0, 0, 0, 4, 0, 0, -4], [0, 0, -10, 0, -2, 20, 7, 0, 0, 0, 20, 0, 0, 0, -10, 0], [0, 0, 0, 19, 0, 0, 0, 0, -7, 0, 0, -1, 0, 1, 0, -5], [0, 0, 3, 0, 0, 5, 0, 0, 0, 18, -5, 0, 0, 0, -3, 0], [8, 0, 0, -5, 0, 0, 0, 0, 5, 0, 0, 0, 10, 0, 0, 5], [0, 4, 8, 0, 0, -8, 0, 0, 0, -12, 8, 0, 0, 0, -8, 0], [0, 0, 0, 11, 0, 0, 0, 0, 8, 0, 0, 3, 0, -3, 0, 6], [0, 0, 1, 0, -6, -7, 12, 0, 0, 0, -7, 0, 0, 0, 1, 0], [0, 0, 0, 22, 0, 0, 0, 0, 12, 0, 0, -2, 0, 2, 0, -6], [0, 0, 0, -25, 0, 0, 0, 0, -3, 0, 0, 4, 0, -4, 0, 3], [0, 4, -16, 0, 0, -13, 0, 0, 0, 32, 13, 0, 0, 0, 16, 0], [0, 0, 5, 0, 1, -15, -1, 0, 0, 0, -15, 0, 0, 0, 5, 0], [42, 0, 0, 3, 0, 0, 0, -5, -3, 0, 0, 1, -11, 1, 0, -3], [0, 0, 0, -18, 0, 0, 0, 0, -6, 0, 0, -7, 0, 7, 0, -6], [0, 2, 7, 0, 0, 1, 0, 0, 0, 8, -1, 0, 0, 0, -7, 0], [18, 0, 0, 1, 0, 0, 0, -10, -1, 0, 0, -5, -12, -5, 0, -1], [0, 0, 0, 16, 0, 0, 0, 0, -5, 0, 0, -1, 0, 1, 0, 14], [0, -4, 8, 0, 0, -14, 0, 0, 0, 24, 14, 0, 0, 0, -8, 0], [0, 0, -20, 0, -22, 5, 4, 0, 0, 0, 5, 0, 0, 0, -20, 0], [0, -2, -8, 0, 0, -11, 0, 0, 0, -14, 11, 0, 0, 0, 8, 0], [0, 0, 0, -8, 0, 0, 0, 0, -3, 0, 0, -1, 0, 1, 0, -8], [0, 0, 0, 7, 0, 0, 0, 0, -10, 0, 0, -2, 0, 2, 0, 6], [0, 0, -3, 0, 2, 5, 2, 0, 0, 0, 5, 0, 0, 0, -3, 0], [0, 0, -8, 0, 17, 1, 7, 0, 0, 0, 1, 0, 0, 0, -8, 0], [0, 0, -7, 0, 2, 0, -2, 0, 0, 0, 0, 0, 0, 0, -7, 0], [2, 0, 0, 10, 0, 0, 0, 14, -10, 0, 0, -7, -6, -7, 0, -10], [-18, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -6, -2, -6, 0, -1], [26, 0, 0, -7, 0, 0, 0, -9, 7, 0, 0, -3, 5, -3, 0, 7], [0, 0, 0, 28, 0, 0, 0, 0, 12, 0, 0, 2, 0, -2, 0, 4], [0, 0, 24, 0, 36, -7, -6, 0, 0, 0, -7, 0, 0, 0, 24, 0], [0, 0, 0, -16, 0, 0, 0, 0, 10, 0, 0, 6, 0, -6, 0, 12], [0, 0, 9, 0, 3, 15, -7, 0, 0, 0, 15, 0, 0, 0, 9, 0], [0, 2, -13, 0, 0, 1, 0, 0, 0, -6, -1, 0, 0, 0, 13, 0], [0, 1, -8, 0, 0, 6, 0, 0, 0, 15, -6, 0, 0, 0, 8, 0], [0, 0, 0, 28, 0, 0, 0, 0, 2, 0, 0, -5, 0, 5, 0, 0], [0, 0, 3, 0, -19, -1, 5, 0, 0, 0, -1, 0, 0, 0, 3, 0], [26, 0, 0, -11, 0, 0, 0, -6, 11, 0, 0, 7, 16, 7, 0, 11], [0, 0, -8, 0, 3, 1, -8, 0, 0, 0, 1, 0, 0, 0, -8, 0], [0, 0, -6, 0, -2, -2, -4, 0, 0, 0, -2, 0, 0, 0, -6, 0], [0, 9, -3, 0, 0, 11, 0, 0, 0, -15, -11, 0, 0, 0, 3, 0], [-48, 0, 0, -3, 0, 0, 0, -6, 3, 0, 0, -6, 0, -6, 0, 3], [0, 0, 0, 3, 0, 0, 0, 0, -10, 0, 0, -4, 0, 4, 0, -15], [0, -3, 5, 0, 0, -1, 0, 0, 0, -1, 1, 0, 0, 0, -5, 0], [0, 0, 6, 0, 6, 14, 6, 0, 0, 0, 14, 0, 0, 0, 6, 0]]
